@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '1.001000';
+our $VERSION = '1.002000';
 
 1;
 
@@ -20,7 +20,7 @@ WebService::MinFraud - API for MaxMind's minFraud Score, Insights, and Factors s
 
 =head1 VERSION
 
-version 1.001000
+version 1.002000
 
 =head1 SYNOPSIS
 
@@ -98,7 +98,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andy Jack Dave Rolsky Greg Oschwald Patrick Cronin
+=for stopwords Andy Jack Dave Rolsky Florian Ragwitz Greg Mark Fowler Olaf Alders Patrick Cronin Ruben Navarro
 
 =over 4
 
@@ -112,12 +112,28 @@ Dave Rolsky <drolsky@maxmind.com>
 
 =item *
 
-Greg Oschwald <goschwald@maxmind.com>
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Greg <goschwald@maxmind.com>
+
+=item *
+
+Mark Fowler <mark@twoshortplanks.com>
+
+=item *
+
+Olaf Alders <oalders@maxmind.com>
 
 =item *
 
 Patrick Cronin <PatrickCronin@users.noreply.github.com>
 
+=item *
+
+Ruben Navarro <rbnx@users.noreply.github.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
