@@ -2,12 +2,13 @@ package WebService::MinFraud::Validator;
 
 use Moo;
 
-our $VERSION = '1.001000';
+our $VERSION = '1.002000';
 
 use Data::Delete 0.05;
 use Data::Rx;
 use Try::Tiny;
 use Types::Standard qw( HashRef InstanceOf Object );
+use WebService::MinFraud::Data::Rx::Type::CCToken;
 use WebService::MinFraud::Data::Rx::Type::DateTime::RFC3339;
 use WebService::MinFraud::Data::Rx::Type::Enum;
 use WebService::MinFraud::Data::Rx::Type::Hex32;
@@ -39,6 +40,7 @@ has _rx => (
                 },
                 type_plugins => [
                     qw(
+                        WebService::MinFraud::Data::Rx::Type::CCToken
                         WebService::MinFraud::Data::Rx::Type::DateTime::RFC3339
                         WebService::MinFraud::Data::Rx::Type::Enum
                         WebService::MinFraud::Data::Rx::Type::Hex32
@@ -111,25 +113,26 @@ sub _build_request_schema_definition {
             credit_card => {
                 type     => '//rec',
                 optional => {
-                    issuer_id_number => {
+                    avs_result => {
                         type   => '//str',
-                        length => { 'min' => 6, 'max' => 6 },
-                    },
-                    last_4_digits => => {
-                        type   => '//str',
-                        length => { 'min' => 4, 'max' => 4 },
+                        length => { 'min' => 1, 'max' => 1 },
                     },
                     bank_name               => '//str',
                     bank_phone_country_code => '//int',
                     bank_phone_number       => '//str',
-                    avs_result              => {
+                    cvv_result              => {
                         type   => '//str',
                         length => { 'min' => 1, 'max' => 1 },
                     },
-                    cvv_result => {
+                    issuer_id_number => {
                         type   => '//str',
-                        length => { 'min' => 1, 'max' => 1 },
+                        length => { 'min' => 6, 'max' => 6 },
                     },
+                    last_4_digits => {
+                        type   => '//str',
+                        length => { 'min' => 4, 'max' => 4 },
+                    },
+                    token => '/maxmind/cctoken',
                 },
             },
             email => {
@@ -349,7 +352,7 @@ WebService::MinFraud::Validator - Validation for the minFraud requests
 
 =head1 VERSION
 
-version 1.001000
+version 1.002000
 
 =head1 SYNOPSIS
 
